==> ws-v3.70.10-src.tar.gz: ws-v3.70-10/src/base/WSCdbDrv.cpp <==
#include <WSCdb.h>
#include <WSCdbDrv.h>

#include "udebug.h"

WSCdbDrvDatabase::WSCdbDrvDatabase()
{
	TRACE_U(("WSCdbDrvDatabase::WSCdbDrvDatabase start"));
	TRACE_U(("WSCdbDrvDatabase::WSCdbDrvDatabase end"));
}
WSCdbDrvDatabase::~WSCdbDrvDatabase()
{
	TRACE_U(("WSCdbDrvDatabase::~WSCdbDrvDatabase"));
	TRACE_U(("WSCdbDrvDatabase::~WSCdbDrvDatabase end"));
}

void WSCdbDrvDatabase::setThisPtr(void* ptr){
  _this = ptr;
}
void* WSCdbDrvDatabase::getThisPtr(){
  return _this;
}

long WSCdbDrvDatabase::open(char* host, char* uid, char* pwd, char* dbname, char* port)
{
	TRACE_U(("WSCdbDrvDatabase::open start"));
	TRACE_U(("WSCdbDrvDatabase::open end"));
	return WS_NO_ERR;
}
long WSCdbDrvDatabase::close()
{
	TRACE_U(("WSCdbDrvDatabase::close start"));
	TRACE_U(("WSCdbDrvDatabase::close end"));
	return WS_NO_ERR;
}
long WSCdbDrvDatabase::beginTran()
{
	TRACE_U(("WSCdbDrvDatabase::beginTran start"));
	TRACE_U(("WSCdbDrvDatabase::beginTran end"));
	return WS_NO_ERR;
}
long WSCdbDrvDatabase::commitTran()
{
	TRACE_U(("WSCdbDrvDatabase::commitTran start"));
	TRACE_U(("WSCdbDrvDatabase::commitTran end"));
	return WS_NO_ERR;
}
long WSCdbDrvDatabase::abortTran()
{
	TRACE_U(("WSCdbDrvDatabase::abortTran start"));
	TRACE_U(("WSCdbDrvDatabase::abortTran end"));
	return WS_NO_ERR;
}
long WSCdbDrvDatabase::sqlExecute(const char* stmt)
{
	TRACE_U(("WSCdbDrvDatabase::sqlExecute start"));
	TRACE_U(("WSCdbDrvDatabase::sqlExecute end"));
	return WS_NO_ERR;
}
WSCbool WSCdbDrvDatabase::isOpen()
{
	return False;
}
void WSCdbDrvDatabase::getError()
{
	TRACE_U(("WSCdbDrvDatabase::getError start"));
	TRACE_U(("WSCdbDrvDatabase::getError end"));
}

void WSCdbDrvDatabase::getErrorMsg(char* szState, char* szMsg)
{
	TRACE_U(("WSCdbDrvDatabase::getErrorMsg start"));
	TRACE_U(("WSCdbDrvDatabase::getErrorMsg end"));
}

void WSCdbDrvDatabase::getErrorMsg(char* szMsg,long size)
{
	TRACE_U(("WSCdbDrvDatabase::getErrorMsg start"));
	TRACE_U(("WSCdbDrvDatabase::getErrorMsg end"));
}
void WSCdbDrvDatabase::setEncode(long code)
{
}
long WSCdbDrvDatabase::getEncode()
{
	return -1;
}



/////
WSCdbDrvRecord::WSCdbDrvRecord(WSCdbDrvDatabase* pDatabase)
{
	TRACE_U(("WSCdbDrvRecord::WSCdbDrvRecord start"));
	TRACE_U(("WSCdbDrvRecord::WSCdbDrvRecord end"));
}
void WSCdbDrvRecord::Cleanup(WSCdbDrvDatabase* pDatabase)
{
}

WSCdbDrvRecord::~WSCdbDrvRecord()
{
	TRACE_U(("WSCdbDrvRecord::~WSCdbDrvRecord start"));
	TRACE_U(("WSCdbDrvRecord::~WSCdbDrvRecord end"));
}
long WSCdbDrvRecord::open(const char* stmt)
{
	return open(stmt, WSCDB_SQL_CURSOR_STATIC, WSCDB_SQL_CONCUR_LOCK);
}
long WSCdbDrvRecord::open(const char* stmt, short eCousor, short eAccess)
{
	TRACE_U(("WSCdbDrvRecord::open start"));
	TRACE_U(("WSCdbDrvRecord::open end"));
	return WS_NO_ERR;
}
long WSCdbDrvRecord::close()
{
	TRACE_U(("WSCdbDrvRecord::close start"));
	TRACE_U(("WSCdbDrvRecord::close end"));
	return WS_NO_ERR;
}
WSCbool WSCdbDrvRecord::isEOF()
{
	return True;
}
WSCbool WSCdbDrvRecord::isOpen()
{
	return False;
}
long WSCdbDrvRecord::getColValue(long index, WSCvariant* var)
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::getColValue(const char* name, WSCvariant* var)
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::getColStringValue(long index, char* var)
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::getColStringValue(const char* name, char* var)
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::setColValue(long index, WSCvariant var)
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::setColValue(const char* name, WSCvariant var)
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::edit()
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::addnew()
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::update()
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::deleterow()
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::moveNext()
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::movePrevious()
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::moveFirst()
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::moveLast()
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::getColName(long index, char* name)
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::getColIndex(const char* name)
{
	return 0;
}
long WSCdbDrvRecord::getColType(long index)
{
	return 0;
}
long WSCdbDrvRecord::getColType(const char* name)
{
	return 0;
}
long WSCdbDrvRecord::getColLength(long index)
{
	return 0;
}
long WSCdbDrvRecord::getColLength(const char* name)
{
	return 0;
}

long WSCdbDrvRecord::getRowCount()
{
	return 0;
}
long WSCdbDrvRecord::getColCount()
{
	return 0;
}
long WSCdbDrvRecord::BindCols()
{
	TRACE_U(("WSCdbDrvRecord::BindCols start"));
	TRACE_U(("WSCdbDrvRecord::BindCols start"));
	return WS_NO_ERR;
}
void WSCdbDrvRecord::ReleaseCols()
{
	TRACE_U(("WSCdbDrvRecord::ReleaseCols start"));
	TRACE_U(("WSCdbDrvRecord::ReleaseCols end"));
}

void WSCdbDrvRecord::getValue(int index, WSCvariant* var)
{
	TRACE_U(("WSCdbDrvRecord::getValue start"));
	TRACE_U(("WSCdbDrvRecord::getValue end"));
}
void WSCdbDrvRecord::setValue(int index, WSCvariant* var)
{
	TRACE_U(("WSCdbDrvRecord::setValue start"));
	TRACE_U(("WSCdbDrvRecord::setValue end"));
}

void WSCdbDrvRecord::getError()
{
	TRACE_U(("WSCdbDrvRecord::getError start"));
	TRACE_U(("WSCdbDrvRecord::getError end"));
}

void WSCdbDrvRecord::getErrorMsg(char* szState, char* szMsg)
{
	TRACE_U(("WSCdbDrvRecord::getErrorMsg start"));
	TRACE_U(("WSCdbDrvRecord::getErrorMsg end"));
}
WSCstring WSCdbDrvRecord::getErrorMessage()
{
	TRACE_U(("WSCdbDrvRecord::getErrorMessage start"));
	TRACE_U(("WSCdbDrvRecord::getErrorMessage end"));
	return "";
}
long WSCdbDrvRecord::isNull(long index)
{
	return 0;
}
long WSCdbDrvRecord::isNull(const char* name)
{
	return 0;
}

==> ws-v3.93.2-src.tar.gz: ws-v3.93-2/src/base/WSCdbDrv.cpp <==
//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//

#include <WScom.h>
#ifndef NO_DB_CLIENT
#include <WSCdb.h>
#include <WSCdbDrv.h>

#include "udebug.h"

WSCdbDrvDatabase::WSCdbDrvDatabase()
{
	TRACE_U(("WSCdbDrvDatabase::WSCdbDrvDatabase start"));
	TRACE_U(("WSCdbDrvDatabase::WSCdbDrvDatabase end"));
}
WSCdbDrvDatabase::~WSCdbDrvDatabase()
{
	TRACE_U(("WSCdbDrvDatabase::~WSCdbDrvDatabase"));
	TRACE_U(("WSCdbDrvDatabase::~WSCdbDrvDatabase end"));
}

void WSCdbDrvDatabase::setThisPtr(void* ptr){
  _this = ptr;
}
void* WSCdbDrvDatabase::getThisPtr(){
  return _this;
}

long WSCdbDrvDatabase::open(char* host, char* uid, char* pwd, char* dbname, char* port)
{
	TRACE_U(("WSCdbDrvDatabase::open start"));
	TRACE_U(("WSCdbDrvDatabase::open end"));
	return WS_NO_ERR;
}
long WSCdbDrvDatabase::close()
{
	TRACE_U(("WSCdbDrvDatabase::close start"));
	TRACE_U(("WSCdbDrvDatabase::close end"));
	return WS_NO_ERR;
}
long WSCdbDrvDatabase::beginTran()
{
	TRACE_U(("WSCdbDrvDatabase::beginTran start"));
	TRACE_U(("WSCdbDrvDatabase::beginTran end"));
	return WS_NO_ERR;
}
long WSCdbDrvDatabase::commitTran()
{
	TRACE_U(("WSCdbDrvDatabase::commitTran start"));
	TRACE_U(("WSCdbDrvDatabase::commitTran end"));
	return WS_NO_ERR;
}
long WSCdbDrvDatabase::abortTran()
{
	TRACE_U(("WSCdbDrvDatabase::abortTran start"));
	TRACE_U(("WSCdbDrvDatabase::abortTran end"));
	return WS_NO_ERR;
}
long WSCdbDrvDatabase::sqlExecute(const char* stmt)
{
	TRACE_U(("WSCdbDrvDatabase::sqlExecute start"));
	TRACE_U(("WSCdbDrvDatabase::sqlExecute end"));
	return WS_NO_ERR;
}
WSCbool WSCdbDrvDatabase::isOpen()
{
	return False;
}
void WSCdbDrvDatabase::getError()
{
	TRACE_U(("WSCdbDrvDatabase::getError start"));
	TRACE_U(("WSCdbDrvDatabase::getError end"));
}

void WSCdbDrvDatabase::getErrorMsg(char* szState, char* szMsg)
{
	TRACE_U(("WSCdbDrvDatabase::getErrorMsg start"));
	TRACE_U(("WSCdbDrvDatabase::getErrorMsg end"));
}

void WSCdbDrvDatabase::getErrorMsg(char* szMsg,long size)
{
	TRACE_U(("WSCdbDrvDatabase::getErrorMsg start"));
	TRACE_U(("WSCdbDrvDatabase::getErrorMsg end"));
}
void WSCdbDrvDatabase::setEncode(long code)
{
}
long WSCdbDrvDatabase::getEncode()
{
	return -1;
}



/////
WSCdbDrvRecord::WSCdbDrvRecord(WSCdbDrvDatabase* pDatabase)
{
	TRACE_U(("WSCdbDrvRecord::WSCdbDrvRecord start"));
	TRACE_U(("WSCdbDrvRecord::WSCdbDrvRecord end"));
}
void WSCdbDrvRecord::Cleanup(WSCdbDrvDatabase* pDatabase)
{
}

WSCdbDrvRecord::~WSCdbDrvRecord()
{
	TRACE_U(("WSCdbDrvRecord::~WSCdbDrvRecord start"));
	TRACE_U(("WSCdbDrvRecord::~WSCdbDrvRecord end"));
}
long WSCdbDrvRecord::open(const char* stmt)
{
	return open(stmt, WSCDB_SQL_CURSOR_STATIC, WSCDB_SQL_CONCUR_LOCK);
}
long WSCdbDrvRecord::open(const char* stmt, short eCousor, short eAccess)
{
	TRACE_U(("WSCdbDrvRecord::open start"));
	TRACE_U(("WSCdbDrvRecord::open end"));
	return WS_NO_ERR;
}
long WSCdbDrvRecord::sendQuery(const char* stmt)
{
	return sendQuery(stmt, WSCDB_SQL_CURSOR_STATIC, WSCDB_SQL_CONCUR_LOCK);
}
long WSCdbDrvRecord::sendQuery(const char* stmt, short eCousor, short eAccess)
{
	TRACE_U(("WSCdbDrvRecord::sendQuery start"));
	TRACE_U(("WSCdbDrvRecord::sendQuery end"));
	return WS_NO_ERR;
}
long WSCdbDrvRecord::close()
{
	TRACE_U(("WSCdbDrvRecord::close start"));
	TRACE_U(("WSCdbDrvRecord::close end"));
	return WS_NO_ERR;
}
long WSCdbDrvRecord::getResult(WSCbool wait)
{
	TRACE_U(("WSCdbDrvRecord::getResult start"));
	TRACE_U(("WSCdbDrvRecord::getResult end"));
	return WS_NO_ERR;
}
long WSCdbDrvRecord::cancelQuery()
{
	TRACE_U(("WSCdbDrvRecord::cancelQuery start"));
	TRACE_U(("WSCdbDrvRecord::cancelQuery end"));
	return WS_NO_ERR;
}
WSCbool WSCdbDrvRecord::isBusy()
{
	return False;
}
WSCbool WSCdbDrvRecord::isEOF()
{
	return True;
}
WSCbool WSCdbDrvRecord::isOpen()
{
	return False;
}
long WSCdbDrvRecord::getColValue(long index, WSCvariant* var)
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::getColValue(const char* name, WSCvariant* var)
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::getColStringValue(long index, char* var)
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::getColStringValue(const char* name, char* var)
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::setColValue(long index, WSCvariant var)
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::setColValue(const char* name, WSCvariant var)
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::edit()
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::addnew()
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::update()
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::deleterow()
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::moveNext()
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::movePrevious()
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::moveFirst()
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::moveLast()
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::getColName(long index, char* name)
{
	return WS_NO_ERR;
}
long WSCdbDrvRecord::getColIndex(const char* name)
{
	return 0;
}
long WSCdbDrvRecord::getColType(long index)
{
	return 0;
}
long WSCdbDrvRecord::getColType(const char* name)
{
	return 0;
}
long WSCdbDrvRecord::getColLength(long index)
{
	return 0;
}
long WSCdbDrvRecord::getColLength(const char* name)
{
	return 0;
}

long WSCdbDrvRecord::getRowCount()
{
	return 0;
}
long WSCdbDrvRecord::getColCount()
{
	return 0;
}
long WSCdbDrvRecord::BindCols()
{
	TRACE_U(("WSCdbDrvRecord::BindCols start"));
	TRACE_U(("WSCdbDrvRecord::BindCols start"));
	return WS_NO_ERR;
}
void WSCdbDrvRecord::ReleaseCols()
{
	TRACE_U(("WSCdbDrvRecord::ReleaseCols start"));
	TRACE_U(("WSCdbDrvRecord::ReleaseCols end"));
}

void WSCdbDrvRecord::getValue(int index, WSCvariant* var)
{
	TRACE_U(("WSCdbDrvRecord::getValue start"));
	TRACE_U(("WSCdbDrvRecord::getValue end"));
}
void WSCdbDrvRecord::setValue(int index, WSCvariant* var)
{
	TRACE_U(("WSCdbDrvRecord::setValue start"));
	TRACE_U(("WSCdbDrvRecord::setValue end"));
}

void WSCdbDrvRecord::getError()
{
	TRACE_U(("WSCdbDrvRecord::getError start"));
	TRACE_U(("WSCdbDrvRecord::getError end"));
}

void WSCdbDrvRecord::getErrorMsg(char* szState, char* szMsg)
{
	TRACE_U(("WSCdbDrvRecord::getErrorMsg start"));
	TRACE_U(("WSCdbDrvRecord::getErrorMsg end"));
}
WSCstring WSCdbDrvRecord::getErrorMessage()
{
	TRACE_U(("WSCdbDrvRecord::getErrorMessage start"));
	TRACE_U(("WSCdbDrvRecord::getErrorMessage end"));
	return "";
}
long WSCdbDrvRecord::isNull(long index)
{
	return 0;
}
long WSCdbDrvRecord::isNull(const char* name)
{
	return 0;
}
#endif //NO_DB_CLIENT
